/// <reference types="@adonisjs/validator" />
declare module "@ioc:Adonis/ClassValidator/Shared" {
    import { ArrayType, BooleanType, CustomMessages, DateType, EnumSetType, EnumType, FileType, NumberType, ObjectType, SchemaArray, SchemaLiteral, SchemaObject, StringType, TypedSchema, ValidatorNode } from "@ioc:Adonis/Core/Validator";
    /**
     * Class constructor.
     */
    type Class<T> = new (...args: any) => T;
    /**
     * Nested schema function.
     */
    type NestedSchemaTypeFn = (nested: TypedSchema) => SchemaType;
    /**
     * Decorator function.
     */
    type DecoratorFn = (target: any, propertyKey: string) => void;
    /**
     * Class validator schema.
     */
    type ClassValidatorBag = {
        messages: CustomMessages;
        schema: TypedSchema;
        key: string;
    };
    /**
     * Types that have members.
     */
    type MemberType = {
        t: {
            [x: string]: any;
        };
        getTree(): SchemaLiteral | SchemaArray | SchemaObject;
    };
    /**
     * Supported class validation base schemas (leverages default Adonis types).
     */
    type SchemaType = ReturnType<StringType> | ReturnType<BooleanType> | ReturnType<NumberType> | ReturnType<DateType> | ReturnType<EnumType> | ReturnType<EnumSetType> | ReturnType<ObjectType> | ReturnType<ArrayType> | ReturnType<FileType> | MemberType;
    /**
     * Append an optional field to the type.
     */
    type WithOptional<T, K extends keyof T> = Omit<T, K> & Partial<Pick<T, K>>;
    /**
     * Class validator argument
     */
    type ClassValidatorArg = Omit<WithOptional<ValidatorNode<any>, "data">, "schema">;
    /**
     * Validate decorator.
     */
    type ValidateDecorator = ((schema: SchemaType, messages?: CustomMessages) => DecoratorFn) & {
        nested: ValidateNestedDecorator<any>;
    };
    /**
     * Nested validate decorator.
     */
    type ValidateNestedDecorator<T> = (nested: Class<T>, schema: NestedSchemaTypeFn, messages?: CustomMessages) => DecoratorFn;
}
