"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validate = void 0;
const utils_1 = require("./utils");
/**
 * Validate a decorated field in a class.
 * @param schema Adonis validation schema for field.
 * @param messages Custom messages for field
 * @returns void
 */
const validate = (schema, messages) => {
    return function (target, propertyKey) {
        const validatorBag = utils_1.getValidatorBag(target);
        validatorBag.schema[propertyKey] = schema;
        validatorBag.messages = Object.assign(Object.assign({}, validatorBag.messages), (messages ? utils_1.transformMessages(propertyKey, messages) : {}));
    };
};
exports.validate = validate;
/**
 * Validated a field with complex type using a custom validator class.
 * @param validatorClass Validator class to use for field.
 * @param schema Adonis validation schema
 * @param messages Custom messages for field.
 * @returns void
 */
exports.validate.nested = (validatorClass, schema, messages) => {
    return function (target, propertyKey) {
        const validatorBag = utils_1.getValidatorBag(target);
        const validatorSchema = schema(utils_1.nested(validatorClass));
        validatorBag.schema[propertyKey] = validatorSchema;
        const isArray = utils_1.schemaIsArray(validatorSchema);
        const validatorClassMessages = utils_1.getValidatorBag(validatorClass).messages;
        validatorBag.messages = Object.assign(Object.assign(Object.assign({}, validatorBag.messages), (messages ? utils_1.transformMessages(propertyKey, messages) : {})), utils_1.transformMessages(propertyKey, validatorClassMessages, isArray));
    };
};
